# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["SuppressionListParams"]


class SuppressionListParams(TypedDict, total=False):
    page: int

    per_page: Annotated[int, PropertyInfo(alias="perPage")]
